{ config, pkgs, mkKdeDerivation, lib, ... }:
{
  imports = [
    ./ark.nix # Archive manager: Compress and decompress
  ];

  nixpkgs.config.permittedInsecurePackages = [
    # Required for neochat
    "olm-3.2.16"
    "dotnet-sdk-6.0.428"
    "dotnet-runtime-6.0.36"
  ];

  users.users.yoda = {
    packages = with pkgs; [
      # Preinstalled
      #   kdePackages.ark # Archive manager
      #   kdePackages.kate # Text editor, e.g. Markdown
      #   kdePackages.gwenview # Image viewer
      #   kdePackages.dolphin-plugins
      #   kdePackages.okular # Document (PDF) viewer
      #   kdePackages.elisa # Music player

      # https://apps.kde.org/

      #
      # KAccounts system
      #
      # Online account providers for the KAccounts system
      # - Adding Nextcloud account
      #   - This error occured:
      #     file:///nix/store/4hzd32dv7f364acshl5rbq12n2h55l4f-kirigami-6.8.0/lib/qt-6/qml/org/kde/kirigami/PageRow.qml:1078: Error: Error while loading page: file:///nix/store/7y720qknhgprbmmv15pc3ipvwn1z33lr-kaccounts-providers-24.08.3/share/kpackage/genericqml/org.kde.kaccounts.nextcloud/contents/ui/WebLogin.qml:11 module "QtWebEngine" plugin "qtwebenginequickplugin" not found
      kdePackages.kaccounts-providers
      kdePackages.kaccounts-integration # Plasma integration components

      # Syncthing tray application and
      # Dolphin + Plasma integration
      syncthingtray

      kdePackages.kgpg # GnuPG GUI
      kdePackages.kleopatra # Encryption keys, encryped files

      kdePackages.kalk # Calculator
      #unstable.kdePackages.falkon # Web browser. Built-in ad blocking.
      #kdePackages.konqueror # Web browser and file manager. Ad filter lists difficutl to set up.
      #kdePackages.angelfish # Web browser. Built-in ad blocking.
      kdePackages.francis # Pomodoro timer.
      kdePackages.ktimer # Timer
      kdePackages.kalarm # Timer
      kdePackages.kclock # Timer and clock
      kdePackages.ktorrent # BitTorrent client
      kdePackages.neochat # Matrix chat client
      #kdePackages.plasmatube # YouTube client (Invidious, Piped).
      kdePackages.tokodon # Fediverse client.
      #unstable.kdePackages.marble # Maps

      rssguard # Rss feed reader with Nextcloud News support.
      #trojita # email

      # Kontact suite
      # https://kontact.kde.org/
      #kdePackages.kontact # Container application for the apps below
      #kdePackages.kmail # email
      kdePackages.kaddressbook # Contacts
      kdePackages.korganizer # Calendar and tasks
      #kdePackages.akregator # RSS feed reader. Does not support Nextcloud News.

      #libsForQt5.plasma-phonebook Contacts
      #kdePackages.calindori # Calendar

      # https://github.com/KDE/merkuro
      #   mekuro-calendar
      #   mekuro-contact
      #   mekuro-mail
      #     - Can't disable HTML view / switch to plain text view -> Tracking images are loaded!
      #kdePackages.merkuro # App suite (email, calendar, contacts, tasks)

      unstable.karp # Arrange PDF files

      #
      # Kate additions
      #
      # KPart to render Markdown
      # https://invent.kde.org/utilities/markdownpart
      # KPart: Plugin framework for user interface components
      # https://api.kde.org/frameworks/kparts/html/index.html
      kdePackages.markdownpart
      # Markdown writing assistance (LSP protocol)
      # E.g. for wiki-links "[[other-doc.md]]"
      # https://docs.zettlr.com/en/academic/zkn-method/#internal-linking
      marksman
    ];
  };
}
