{ config, pkgs, ... }:
{
  # Alternative: Install Steam as Flatpak
  #
  # https://wiki.archlinux.org/title/steam#See_also
  # flatpak install com.valvesoftware.Steam
  #
  # Launching Steam with Flatpak might warn you about installing the steam-devices package to add support for some gamepads.
  #   https://wiki.archlinux.org/title/steam#Flatpak
  #   https://github.com/ValveSoftware/steam-devices
  # These udev rules should be enabled by the following setting.
  #   https://www.reddit.com/r/NixOS/comments/10px9ty/comment/j6moarv/
  #hardware.steam-hardware.enable = true;

  # AMD GPU driver.
  #
  # https://nixos.wiki/wiki/Steam#Changing_the_driver_on_AMD_GPUs
  # According to this wiki, it can help to try out different drivers.

  # https://nixos.wiki/wiki/Steam#Install
  programs.steam = {
    enable = true;

    # Open ports in the firewall for Steam Remote Play
    #remotePlay.openFirewall = true;

    # Open ports in the firewall for Source Dedicated Server
    # https://developer.valvesoftware.com/wiki/Source_Dedicated_Server
    # Tool that runs the server component of a Source game (CS:GO, etc) without the client component
    #dedicatedServer.openFirewall = true;

    localNetworkGameTransfers.openFirewall = true; # Open ports in the firewall for Steam Local Network Game Transfers
  };
  allowUnfree = [
    "steam"
    "steam-original"
    "steam-unwrapped"
    "steam-run"
  ];
}
